
Authors
=======

* Philippe Fleischmann <fleischmann@arch.ethz.ch> `@fleischp <https://github.com/fleischp>`_
* Gonzalo Casas <casas@arch.ethz.ch> `@gonzalocasas <https://github.com/gonzalocasas>`_
* Michael Lyrenmann <lyrenmann@arch.ethz.ch>
